@@ -1,12 +1,15 @@
 package aQute.bnd.metatype;
 
-import java.io.*;
+import java.io.OutputStream;
+import java.io.OutputStreamWriter;
+import java.io.PrintWriter;
+import java.io.UnsupportedEncodingException;
 
-import aQute.bnd.osgi.*;
-import aQute.lib.tag.*;
+import aQute.bnd.osgi.WriteResource;
+import aQute.lib.tag.Tag;
 
 public class TagResource extends WriteResource {
-	final Tag	tag;
+	final Tag tag;
 
 	public TagResource(Tag tag) {
 		this.tag = tag;
@@ -16,11 +19,10 @@ public class TagResource extends WriteResource {
 	public void write(OutputStream out) throws UnsupportedEncodingException {
 		OutputStreamWriter ow = new OutputStreamWriter(out, "UTF-8");
 		PrintWriter pw = new PrintWriter(ow);
-		pw.println("<?xml version=\"1.0\"?>");
+		pw.print("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
 		try {
 			tag.print(0, pw);
-		}
-		finally {
+		} finally {
 			pw.flush();
 		}
 	}
