@@ -1,6 +1,13 @@
 package aQute.bnd.osgi;
 
-import java.io.*;
+import java.io.BufferedReader;
+import java.io.ByteArrayOutputStream;
+import java.io.InputStream;
+import java.io.InputStreamReader;
+import java.io.OutputStreamWriter;
+import java.io.PrintWriter;
+
+import aQute.lib.io.IO;
 
 public class PreprocessResource extends AbstractResource {
 	final Resource	resource;
@@ -33,10 +40,10 @@ public class PreprocessResource extends AbstractResource {
 			byte[] data = bout.toByteArray();
 			return data;
 
-		} catch( Exception e) {
-			throw new IllegalArgumentException("Invalid resource to pre-process, likely binary");
-		}
-		finally {
+		} catch (Exception e) {
+			return IO.read(resource.openInputStream());
+
+		} finally {
 			if (rdr != null) {
 				rdr.close();
 			}
