@@ -1,9 +1,10 @@
 package aQute.lib.collections;
 
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Iterator;
 
 public class IteratorList<T> extends ArrayList<T> {
-	private static final long	serialVersionUID	= 1L;
+	private static final long serialVersionUID = 1L;
 
 	public IteratorList(Iterator<T> i) {
 		while (i.hasNext())
